# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class AnalyticSetOperations(object):
    """AnalyticSetOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_analytic_set_groups(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """Returns a collection of analytic set groups.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_analytic_set_groups.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_analytic_set_groups.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytic-set-groups'}

    def get_analytic_set_group(
            self, ems_system_id, group_id, custom_headers=None, raw=False, **operation_config):
        """Returns an analytic set group.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param group_id: The ID of the analytic set group to return.
        :type group_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_analytic_set_group.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'groupId': self._serialize.url("group_id", group_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_analytic_set_group.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytic-set-groups/{groupId}'}

    def get_parameter_sets(
            self, ems_system_id, group_id, analytic_set_name, custom_headers=None, raw=False, **operation_config):
        """Returns an analytic set with the provided name from the group
        requested.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param group_id: The ID of the analytic set group to retrieve the
         analytic set from.
        :type group_id: str
        :param analytic_set_name: The name of the analytic set to return.
        :type analytic_set_name: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_parameter_sets.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'groupId': self._serialize.url("group_id", group_id, 'str'),
            'analyticSetName': self._serialize.url("analytic_set_name", analytic_set_name, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticSetAnalyticSet', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_parameter_sets.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytic-set-groups/{groupId}/analytic-sets/{analyticSetName}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadProcessingStatus(Model):
    """Represents the status of an upload processing through EMS.

    :param download_record: The upload's download record, if known
    :type download_record: int
    :param download_state: A description of the download record's processing
     state. This should be checked before assuming
     that the download is correct and complete. Possible values include:
     'notProcessed', 'processed', 'failure'
    :type download_state: str or ~emsapi.models.enum
    :param flights: The upload's flight information, if known
    :type flights:
     list[~emsapi.models.AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus]
    :param error_message: Any error message associated with the processing of
     the upload, if any
    :type error_message: str
    """

    _attribute_map = {
        'download_record': {'key': 'downloadRecord', 'type': 'int'},
        'download_state': {'key': 'downloadState', 'type': 'str'},
        'flights': {'key': 'flights', 'type': '[AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus]'},
        'error_message': {'key': 'errorMessage', 'type': 'str'},
    }

    def __init__(self, *, download_record: int=None, download_state=None, flights=None, error_message: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoUploadUploadProcessingStatus, self).__init__(**kwargs)
        self.download_record = download_record
        self.download_state = download_state
        self.flights = flights
        self.error_message = error_message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestTags(Model):
    """AdiEmsWebSharedTableauRestTags.

    :param tag:
    :type tag: list[~emsapi.models.AdiEmsWebSharedTableauRestTag]
    """

    _attribute_map = {
        'tag': {'key': 'tag', 'type': '[AdiEmsWebSharedTableauRestTag]'},
    }

    def __init__(self, *, tag=None, **kwargs) -> None:
        super(AdiEmsWebSharedTableauRestTags, self).__init__(**kwargs)
        self.tag = tag



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQueryResult(Model):
    """Represents the tabular results of a data source query.

    All required parameters must be populated in order to send to Azure.

    :param header: Required. An ordered list of header column information,
     describing the fields included in the results and matching
     the order of columns in the resulting data rows
    :type header:
     list[~emsapi.models.AdiEmsWebApiV2DtoSchemaQueryResultHeader]
    :param rows: Required. An array of arrays representing the resulting data
     rows of a query. Each inner array represents a single
     results row
    :type rows: list[list[object]]
    :param is_partial_result: Required. Indicates whether the rows returned
     are a partial query result because the maximum amount of rows that can
     be returned has been reached.
    :type is_partial_result: bool
    """

    _validation = {
        'header': {'required': True},
        'rows': {'required': True},
        'is_partial_result': {'required': True},
    }

    _attribute_map = {
        'header': {'key': 'header', 'type': '[AdiEmsWebApiV2DtoSchemaQueryResultHeader]'},
        'rows': {'key': 'rows', 'type': '[[object]]'},
        'is_partial_result': {'key': 'isPartialResult', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaQueryResult, self).__init__(**kwargs)
        self.header = kwargs.get('header', None)
        self.rows = kwargs.get('rows', None)
        self.is_partial_result = kwargs.get('is_partial_result', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class AssetOperations(object):
    """AssetOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_fleets(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """Returns the list of fleets the user has access to in their security
        context.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_fleets.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAssetFleet]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_fleets.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/fleets'}

    def get_fleet(
            self, ems_system_id, fleet_id, custom_headers=None, raw=False, **operation_config):
        """Returns information for a fleet on the system.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param fleet_id: The unique identifier of the fleet of interest.
        :type fleet_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_fleet.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'fleetId': self._serialize.url("fleet_id", fleet_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAssetFleet', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_fleet.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/fleets/{fleetId}'}

    def get_aircraft(
            self, ems_system_id, fleet_id=None, custom_headers=None, raw=False, **operation_config):
        """Returns the list of aircraft the user has access to in their security
        context.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param fleet_id: If specified, returns only the aircraft belonging to
         the indicated fleet.
        :type fleet_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_aircraft.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if fleet_id is not None:
            query_parameters['fleetId'] = self._serialize.query("fleet_id", fleet_id, 'int')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAssetAircraft]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_aircraft.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/aircraft'}

    def get_aircraft_by_id(
            self, ems_system_id, aircraft_id, custom_headers=None, raw=False, **operation_config):
        """Returns information for an aircraft on the system.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param aircraft_id: The unique identifier of the aircraft of interest.
        :type aircraft_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_aircraft_by_id.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'aircraftId': self._serialize.url("aircraft_id", aircraft_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAssetAircraft', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_aircraft_by_id.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/aircraft/{aircraftId}'}

    def get_flight_phases(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """Returns the list of flight phases.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_flight_phases.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAssetFlightPhase]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_flight_phases.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/flight-phases'}

    def get_flight_phase(
            self, ems_system_id, flight_phase_id, custom_headers=None, raw=False, **operation_config):
        """Returns information for a flight phase on the system.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_phase_id: The unique identifier of the flight phase of
         interest.
        :type flight_phase_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_flight_phase.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightPhaseId': self._serialize.url("flight_phase_id", flight_phase_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAssetFlightPhase', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_flight_phase.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/flight-phases/{flightPhaseId}'}

    def get_airports(
            self, ems_system_id, include_all=None, custom_headers=None, raw=False, **operation_config):
        """Returns the list of airports that have been visited by the EMS system
        or all the airports available
        on the EMS system.

        If includeAll is left as false just the airports that are significant
        to the flight data are included.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param include_all: If true, include all the airports on this EMS
         system. Defaults to false.
        :type include_all: bool
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_airports.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if include_all is not None:
            query_parameters['includeAll'] = self._serialize.query("include_all", include_all, 'bool')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAssetAirport]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_airports.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/airports'}

    def get_airport(
            self, ems_system_id, airport_id, custom_headers=None, raw=False, **operation_config):
        """Returns information for an airport on the system.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param airport_id: The unique identifier of the airport of interest.
        :type airport_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_airport.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'airportId': self._serialize.url("airport_id", airport_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAssetAirport', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_airport.metadata = {'url': '/v2/ems-systems/{emsSystemId}/assets/airports/{airportId}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaAsyncQueryInfo(Model):
    """Passed back to the client when an async query is started. This contains
    query header
    information, and a unique ID, with which the user can later read data for
    this query.

    :param id: The ID of the query; this will be used when making subsequent
     calls to the query APIs.
    :type id: str
    :param inactivity_timeout: The number of seconds of inactivity after which
     an async query is eligible for automatic deletion.
    :type inactivity_timeout: int
    :param header: An ordered list of header column information, describing
     the fields included in the results and matching
     the order of columns in the resulting data rows.
    :type header:
     list[~emsapi.models.AdiEmsWebApiV2DtoSchemaQueryResultHeader]
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'inactivity_timeout': {'key': 'inactivityTimeout', 'type': 'int'},
        'header': {'key': 'header', 'type': '[AdiEmsWebApiV2DtoSchemaQueryResultHeader]'},
    }

    def __init__(self, *, id: str=None, inactivity_timeout: int=None, header=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaAsyncQueryInfo, self).__init__(**kwargs)
        self.id = id
        self.inactivity_timeout = inactivity_timeout
        self.header = header



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQueryResultHeader(Model):
    """Represents a header column in data source query result.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier of the field associated
     with this column
    :type id: str
    :param name: Required. The user-friendly display name of the field
     associated with this column
    :type name: str
    :param units: The units of values of the field associated with this
     column. This value may be empty if not applicable
    :type units: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'units': {'key': 'units', 'type': 'str'},
    }

    def __init__(self, *, id: str, name: str, units: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaQueryResultHeader, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.units = units



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaDatabase(Model):
    """Represents a database type exposed by an EMS installation.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier for the database
    :type id: str
    :param plural_name: Required. A plural display name for the database
    :type plural_name: str
    :param singular_name: Required. A singular display name for the database
    :type singular_name: str
    """

    _validation = {
        'id': {'required': True},
        'plural_name': {'required': True},
        'singular_name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'plural_name': {'key': 'pluralName', 'type': 'str'},
        'singular_name': {'key': 'singularName', 'type': 'str'},
    }

    def __init__(self, *, id: str, plural_name: str, singular_name: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaDatabase, self).__init__(**kwargs)
        self.id = id
        self.plural_name = plural_name
        self.singular_name = singular_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.service_client import SDKClient
from msrest import Configuration, Serializer, Deserializer
from .version import VERSION
from msrest.exceptions import HttpOperationError
from .operations.analytic_operations import AnalyticOperations
from .operations.analytic_set_operations import AnalyticSetOperations
from .operations.asset_operations import AssetOperations
from .operations.database_operations import DatabaseOperations
from .operations.ems_profile_operations import EmsProfileOperations
from .operations.ems_system_operations import EmsSystemOperations
from .operations.html_documentation_operations import HtmlDocumentationOperations
from .operations.navigation_operations import NavigationOperations
from .operations.parameter_set_operations import ParameterSetOperations
from .operations.profile_operations import ProfileOperations
from .operations.tableau_operations import TableauOperations
from .operations.trajectory_operations import TrajectoryOperations
from .operations.transfer_operations import TransferOperations
from .operations.upload_operations import UploadOperations
from .operations.weather_operations import WeatherOperations
from . import models


class emsapiConfiguration(Configuration):
    """Configuration for emsapi
    Note that all parameters used to create this instance are saved as instance
    attributes.

    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, base_url=None):

        if credentials is None:
            raise ValueError("Parameter 'credentials' must not be None.")
        if not base_url:
            base_url = 'https://ems.efoqa.com:443/api'

        super(emsapiConfiguration, self).__init__(base_url)

        self.add_user_agent('emsapi/{}'.format(VERSION))

        self.credentials = credentials


class emsapi(SDKClient):
    """The second version of the REST-based API for accessing EMS data

    :ivar config: Configuration for client.
    :vartype config: emsapiConfiguration

    :ivar analytic: Analytic operations
    :vartype analytic: emsapi.operations.AnalyticOperations
    :ivar analytic_set: AnalyticSet operations
    :vartype analytic_set: emsapi.operations.AnalyticSetOperations
    :ivar asset: Asset operations
    :vartype asset: emsapi.operations.AssetOperations
    :ivar database: Database operations
    :vartype database: emsapi.operations.DatabaseOperations
    :ivar ems_profile: EmsProfile operations
    :vartype ems_profile: emsapi.operations.EmsProfileOperations
    :ivar ems_system: EmsSystem operations
    :vartype ems_system: emsapi.operations.EmsSystemOperations
    :ivar html_documentation: HtmlDocumentation operations
    :vartype html_documentation: emsapi.operations.HtmlDocumentationOperations
    :ivar navigation: Navigation operations
    :vartype navigation: emsapi.operations.NavigationOperations
    :ivar parameter_set: ParameterSet operations
    :vartype parameter_set: emsapi.operations.ParameterSetOperations
    :ivar profile: Profile operations
    :vartype profile: emsapi.operations.ProfileOperations
    :ivar tableau: Tableau operations
    :vartype tableau: emsapi.operations.TableauOperations
    :ivar trajectory: Trajectory operations
    :vartype trajectory: emsapi.operations.TrajectoryOperations
    :ivar transfer: Transfer operations
    :vartype transfer: emsapi.operations.TransferOperations
    :ivar upload: Upload operations
    :vartype upload: emsapi.operations.UploadOperations
    :ivar weather: Weather operations
    :vartype weather: emsapi.operations.WeatherOperations

    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, base_url=None):

        self.config = emsapiConfiguration(credentials, base_url)
        super(emsapi, self).__init__(self.config.credentials, self.config)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self.api_version = 'v2'
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)

        self.analytic = AnalyticOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.analytic_set = AnalyticSetOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.asset = AssetOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.database = DatabaseOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.ems_profile = EmsProfileOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.ems_system = EmsSystemOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.html_documentation = HtmlDocumentationOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.navigation = NavigationOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.parameter_set = ParameterSetOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.profile = ProfileOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.tableau = TableauOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.trajectory = TrajectoryOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.transfer = TransferOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.upload = UploadOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.weather = WeatherOperations(
            self._client, self.config, self._serialize, self._deserialize)

    @staticmethod
    def create(username, password, url='https://ems.efoqa.com/api'):
        """Creates a new instance of EMS API client. This client will automatically manage 
        API tokens for the given username/password.
        
        :param username: The username to use for authentication.
        :type username: str
        :param password: The password to use for authentication.
        :type password: str
        :param url: The EMS API endpoint to connect to (default: {'https://ems.efoqa.com/api'})
        :type url: str
        """
        from .extensions import EmsApiTokenAuthentication
        session = EmsApiTokenAuthentication(username, password, url)
        return emsapi(session, url)

    def find_ems_system_id(self, name):
        """Finds the EMS system id for the given name.
        
        :param name: The EMS system name to search for.
        :type name: str
        """
        from .extensions import EmsSystemHelper
        return EmsSystemHelper.find_id(self, name)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQueryResultHeader(Model):
    """Represents a header column in data source query result.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier of the field associated
     with this column
    :type id: str
    :param name: Required. The user-friendly display name of the field
     associated with this column
    :type name: str
    :param units: The units of values of the field associated with this
     column. This value may be empty if not applicable
    :type units: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'units': {'key': 'units', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaQueryResultHeader, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.units = kwargs.get('units', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestWorkbook(Model):
    """AdiEmsWebSharedTableauRestWorkbook.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param content_url:
    :type content_url: str
    :param show_tabs:
    :type show_tabs: bool
    :param size:
    :type size: int
    :param created_at:
    :type created_at: datetime
    :param updated_at:
    :type updated_at: datetime
    :param project:
    :type project: ~emsapi.models.AdiEmsWebSharedTableauRestProject
    :param owner:
    :type owner: ~emsapi.models.AdiEmsWebSharedTableauRestUser
    :param tags:
    :type tags: ~emsapi.models.AdiEmsWebSharedTableauRestTags
    :param views:
    :type views: ~emsapi.models.AdiEmsWebSharedTableauRestViews
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'content_url': {'key': 'contentUrl', 'type': 'str'},
        'show_tabs': {'key': 'showTabs', 'type': 'bool'},
        'size': {'key': 'size', 'type': 'int'},
        'created_at': {'key': 'createdAt', 'type': 'iso-8601'},
        'updated_at': {'key': 'updatedAt', 'type': 'iso-8601'},
        'project': {'key': 'project', 'type': 'AdiEmsWebSharedTableauRestProject'},
        'owner': {'key': 'owner', 'type': 'AdiEmsWebSharedTableauRestUser'},
        'tags': {'key': 'tags', 'type': 'AdiEmsWebSharedTableauRestTags'},
        'views': {'key': 'views', 'type': 'AdiEmsWebSharedTableauRestViews'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebSharedTableauRestWorkbook, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.content_url = kwargs.get('content_url', None)
        self.show_tabs = kwargs.get('show_tabs', None)
        self.size = kwargs.get('size', None)
        self.created_at = kwargs.get('created_at', None)
        self.updated_at = kwargs.get('updated_at', None)
        self.project = kwargs.get('project', None)
        self.owner = kwargs.get('owner', None)
        self.tags = kwargs.get('tags', None)
        self.views = kwargs.get('views', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherMetarMetarReport(Model):
    """Represents an individual METAR report.

    All required parameters must be populated in order to send to Azure.

    :param unparsed: Required. The unparsed but de-identified METAR string
    :type unparsed: str
    :param airport: Required. The airport that issued the METAR report
    :type airport: str
    :param issued: The day, hour and minute the METAR was issued. May also
     optionally contain the month and year issued if the
     date contextual information is available
    :type issued: datetime
    :param is_automatic: Required. Indicates whether the original METAR data
     was automatically generated
    :type is_automatic: bool
    :param wind_direction: The wind direction in degrees or, if wind is
     variable this will be zero
    :type wind_direction: float
    :param wind_speed: The wind speed in knots
    :type wind_speed: float
    :param wind_gust_speed: The wind gust speed in knots, if wind gust data is
     present
    :type wind_gust_speed: float
    :param wind_direction_variable_start: When wind is variable, the
     approximate end range of the wind direction in degrees
    :type wind_direction_variable_start: float
    :param wind_direction_variable_end: When wind is variable, the approximate
     end range of the wind direction in degrees
    :type wind_direction_variable_end: float
    :param effective_visibility: The effective visibility in statute miles
    :type effective_visibility: float
    :param exact_visibility: The exact reported visibility in statute miles.
     Uses "Infinity" to indicate there is no limit
    :type exact_visibility: float
    :param visibility_qualifier: A qualifier describing the current exact
     reported visibility. Possible values include: 'equal', 'greaterThan',
     'lessThan'
    :type visibility_qualifier: str or ~emsapi.models.enum
    :param runway_visual_ranges: A list of runway visual ranges for reported
     runways
    :type runway_visual_ranges:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange]
    :param current_weather: A list of current weather phenomenons
    :type current_weather:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherWeatherPhenomenon]
    :param recent_weather: A list of recently occurring weather phenomenons
    :type recent_weather:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherWeatherPhenomenon]
    :param is_weather_data_valid: Required. Indicates whether all
     current/recent reported weather phenomenons had valid sensor data
    :type is_weather_data_valid: bool
    :param cloud_conditions: A list of current cloud conditions
    :type cloud_conditions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherCloudCondition]
    :param ceiling: The lowest "Broken", "Overcast" or "Vertical Visibility"
     cloud conditions associated with this object
    :type ceiling: ~emsapi.models.AdiEmsWebApiV2DtoWeatherCloudCondition
    :param is_cloud_data_valid: Required. Indicates whether all reported cloud
     conditions had valid sensor data
    :type is_cloud_data_valid: bool
    :param max_cloud_height: The maximum height of the base of a visual
     portion of one of the cloud conditions associated with this
     object. Uses "Infinity" to indicate there is no limit
    :type max_cloud_height: float
    :param temperature: The current temperature value in degrees Celsius
    :type temperature: float
    :param dewpoint: The current dew point value in degrees Celsius
    :type dewpoint: float
    :param pressure: Pressure above ground level in inches of mercury
    :type pressure: float
    :param runway_conditions: A list of current runway conditions
    :type runway_conditions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarRunwayCondition]
    :param flight_match_type: The time and place relative to a specific flight
     that this METAR data would match to. Possible values include: 'none',
     'takeoff', 'landing'
    :type flight_match_type: str or ~emsapi.models.enum
    """

    _validation = {
        'unparsed': {'required': True},
        'airport': {'required': True},
        'is_automatic': {'required': True},
        'is_weather_data_valid': {'required': True},
        'is_cloud_data_valid': {'required': True},
    }

    _attribute_map = {
        'unparsed': {'key': 'unparsed', 'type': 'str'},
        'airport': {'key': 'airport', 'type': 'str'},
        'issued': {'key': 'issued', 'type': 'iso-8601'},
        'is_automatic': {'key': 'isAutomatic', 'type': 'bool'},
        'wind_direction': {'key': 'windDirection', 'type': 'float'},
        'wind_speed': {'key': 'windSpeed', 'type': 'float'},
        'wind_gust_speed': {'key': 'windGustSpeed', 'type': 'float'},
        'wind_direction_variable_start': {'key': 'windDirectionVariableStart', 'type': 'float'},
        'wind_direction_variable_end': {'key': 'windDirectionVariableEnd', 'type': 'float'},
        'effective_visibility': {'key': 'effectiveVisibility', 'type': 'float'},
        'exact_visibility': {'key': 'exactVisibility', 'type': 'float'},
        'visibility_qualifier': {'key': 'visibilityQualifier', 'type': 'str'},
        'runway_visual_ranges': {'key': 'runwayVisualRanges', 'type': '[AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange]'},
        'current_weather': {'key': 'currentWeather', 'type': '[AdiEmsWebApiV2DtoWeatherWeatherPhenomenon]'},
        'recent_weather': {'key': 'recentWeather', 'type': '[AdiEmsWebApiV2DtoWeatherWeatherPhenomenon]'},
        'is_weather_data_valid': {'key': 'isWeatherDataValid', 'type': 'bool'},
        'cloud_conditions': {'key': 'cloudConditions', 'type': '[AdiEmsWebApiV2DtoWeatherCloudCondition]'},
        'ceiling': {'key': 'ceiling', 'type': 'AdiEmsWebApiV2DtoWeatherCloudCondition'},
        'is_cloud_data_valid': {'key': 'isCloudDataValid', 'type': 'bool'},
        'max_cloud_height': {'key': 'maxCloudHeight', 'type': 'float'},
        'temperature': {'key': 'temperature', 'type': 'float'},
        'dewpoint': {'key': 'dewpoint', 'type': 'float'},
        'pressure': {'key': 'pressure', 'type': 'float'},
        'runway_conditions': {'key': 'runwayConditions', 'type': '[AdiEmsWebApiV2DtoWeatherMetarRunwayCondition]'},
        'flight_match_type': {'key': 'flightMatchType', 'type': 'str'},
    }

    def __init__(self, *, unparsed: str, airport: str, is_automatic: bool, is_weather_data_valid: bool, is_cloud_data_valid: bool, issued=None, wind_direction: float=None, wind_speed: float=None, wind_gust_speed: float=None, wind_direction_variable_start: float=None, wind_direction_variable_end: float=None, effective_visibility: float=None, exact_visibility: float=None, visibility_qualifier=None, runway_visual_ranges=None, current_weather=None, recent_weather=None, cloud_conditions=None, ceiling=None, max_cloud_height: float=None, temperature: float=None, dewpoint: float=None, pressure: float=None, runway_conditions=None, flight_match_type=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherMetarMetarReport, self).__init__(**kwargs)
        self.unparsed = unparsed
        self.airport = airport
        self.issued = issued
        self.is_automatic = is_automatic
        self.wind_direction = wind_direction
        self.wind_speed = wind_speed
        self.wind_gust_speed = wind_gust_speed
        self.wind_direction_variable_start = wind_direction_variable_start
        self.wind_direction_variable_end = wind_direction_variable_end
        self.effective_visibility = effective_visibility
        self.exact_visibility = exact_visibility
        self.visibility_qualifier = visibility_qualifier
        self.runway_visual_ranges = runway_visual_ranges
        self.current_weather = current_weather
        self.recent_weather = recent_weather
        self.is_weather_data_valid = is_weather_data_valid
        self.cloud_conditions = cloud_conditions
        self.ceiling = ceiling
        self.is_cloud_data_valid = is_cloud_data_valid
        self.max_cloud_height = max_cloud_height
        self.temperature = temperature
        self.dewpoint = dewpoint
        self.pressure = pressure
        self.runway_conditions = runway_conditions
        self.flight_match_type = flight_match_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationWaypoint(Model):
    """Various pieces of information associated with a waypoint.

    :param id: The unique identifier of the waypoint.
    :type id: int
    :param airport_id: The airport id for the waypoint, if any.
    :type airport_id: int
    :param country_code: The country code of the waypoint.
    :type country_code: str
    :param type: The type of the waypoint.
    :type type: str
    :param name: The name of the waypoint.
    :type name: str
    :param icao_code: The ICAO code of the waypoint.
    :type icao_code: str
    :param usage_code: The usage code of the waypoint.
    :type usage_code: str
    :param latitude: The latitude of the waypoint.
    :type latitude: float
    :param longitude: The longitude of the waypoint.
    :type longitude: float
    :param magnetic_variance: The magnetic variance from true north at the
     waypoint.
    :type magnetic_variance: float
    :param navaid_id: The id of the associated naviad, if any.
    :type navaid_id: int
    :param colocation_flag: Flag indicating whether or not the waypoint is
     colocated with the navaid.
    :type colocation_flag: bool
    :param navaid_bearing: The magnetic bearing from the navaid to the
     waypoint.
    :type navaid_bearing: float
    :param navaid_distance: The distance from the navaid to the waypoint.
    :type navaid_distance: float
    :param dafif_id: The DAFIF text identifier of the waypoint.
    :type dafif_id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'airport_id': {'key': 'airportId', 'type': 'int'},
        'country_code': {'key': 'countryCode', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'icao_code': {'key': 'icaoCode', 'type': 'str'},
        'usage_code': {'key': 'usageCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'magnetic_variance': {'key': 'magneticVariance', 'type': 'float'},
        'navaid_id': {'key': 'navaidId', 'type': 'int'},
        'colocation_flag': {'key': 'colocationFlag', 'type': 'bool'},
        'navaid_bearing': {'key': 'navaidBearing', 'type': 'float'},
        'navaid_distance': {'key': 'navaidDistance', 'type': 'float'},
        'dafif_id': {'key': 'dafifId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoNavigationNavigationWaypoint, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.airport_id = kwargs.get('airport_id', None)
        self.country_code = kwargs.get('country_code', None)
        self.type = kwargs.get('type', None)
        self.name = kwargs.get('name', None)
        self.icao_code = kwargs.get('icao_code', None)
        self.usage_code = kwargs.get('usage_code', None)
        self.latitude = kwargs.get('latitude', None)
        self.longitude = kwargs.get('longitude', None)
        self.magnetic_variance = kwargs.get('magnetic_variance', None)
        self.navaid_id = kwargs.get('navaid_id', None)
        self.colocation_flag = kwargs.get('colocation_flag', None)
        self.navaid_bearing = kwargs.get('navaid_bearing', None)
        self.navaid_distance = kwargs.get('navaid_distance', None)
        self.dafif_id = kwargs.get('dafif_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadRecord(Model):
    """Represents one record in the list of uploads that we know about on the
    server side.

    :param id: The transfer ID of the transfer, set by the server when the
     transfer started
    :type id: str
    :param type: The type of the upload. Possible values include:
     'emsCollectionZipped', 'testTransfer', 'emsCollectionRaw'
    :type type: str or ~emsapi.models.enum
    :param name: Name field set by the client when the transfer started
    :type name: str
    :param current_count: The current number of bytes transferred
    :type current_count: long
    :param total_size: The total size of the transfer, if known
    :type total_size: long
    :param last_transfer: The timestamp of the last time someone uploaded
     bytes to this transfer. This will
     be used to determine when a transfer can be aborted automatically
    :type last_transfer: datetime
    :param last_processing: The timestamp of the last time someone tried to
     process this transfer. This will
     be used to determine when a transfer can be aborted automatically
    :type last_processing: datetime
    :param start_time: The start time of the transfer, from when the initial
     start request is made
    :type start_time: datetime
    :param transfer_finish_time: The finish time of the actual data transfer
     portion of the process
    :type transfer_finish_time: datetime
    :param processing_finish_time: The finish time of the processing portion
     of the process
    :type processing_finish_time: datetime
    :param state: The state of the upload, up to and including EMS hand-off.
     Possible values include: 'transferring', 'waitingProcessing',
     'processing', 'processedSuccess', 'processedFailure', 'abandonedTransfer',
     'abandonedProcessing', 'canceled'
    :type state: str or ~emsapi.models.enum
    :param metadata: Metadata for the upload; this is somewhat arbitrary and
     specific to the type
     of the transfer, but in any event, it will be a JSON blob with key/value
     pairs
    :type metadata: dict[str, str]
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'current_count': {'key': 'currentCount', 'type': 'long'},
        'total_size': {'key': 'totalSize', 'type': 'long'},
        'last_transfer': {'key': 'lastTransfer', 'type': 'iso-8601'},
        'last_processing': {'key': 'lastProcessing', 'type': 'iso-8601'},
        'start_time': {'key': 'startTime', 'type': 'iso-8601'},
        'transfer_finish_time': {'key': 'transferFinishTime', 'type': 'iso-8601'},
        'processing_finish_time': {'key': 'processingFinishTime', 'type': 'iso-8601'},
        'state': {'key': 'state', 'type': 'str'},
        'metadata': {'key': 'metadata', 'type': '{str}'},
    }

    def __init__(self, *, id: str=None, type=None, name: str=None, current_count: int=None, total_size: int=None, last_transfer=None, last_processing=None, start_time=None, transfer_finish_time=None, processing_finish_time=None, state=None, metadata=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoUploadUploadRecord, self).__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name
        self.current_count = current_count
        self.total_size = total_size
        self.last_transfer = last_transfer
        self.last_processing = last_processing
        self.start_time = start_time
        self.transfer_finish_time = transfer_finish_time
        self.processing_finish_time = processing_finish_time
        self.state = state
        self.metadata = metadata



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAssetFlightPhase(Model):
    """A flight phase is a coarse division of a flight into sections, such as
    takeoff, climb and enroute.
    The flight phases are used as inputs into some analytics.

    :param id: The identifier of the flight phase within the system.
    :type id: int
    :param description: The description for this phase of flight.
    :type description: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoAssetFlightPhase, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.description = kwargs.get('description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestViews(Model):
    """AdiEmsWebSharedTableauRestViews.

    :param view:
    :type view: list[~emsapi.models.AdiEmsWebSharedTableauRestView]
    """

    _attribute_map = {
        'view': {'key': 'view', 'type': '[AdiEmsWebSharedTableauRestView]'},
    }

    def __init__(self, *, view=None, **kwargs) -> None:
        super(AdiEmsWebSharedTableauRestViews, self).__init__(**kwargs)
        self.view = view



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaSelectColumn(Model):
    """Represents a column of data that can be selected in a data source query.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. The unique string identifier of the field to
     select in a query
    :type field_id: str
    :param aggregate: An optional aggregate operation to perform on the
     column. Omission of this property results in no aggregate
     operation being performed. Possible values include: 'none', 'avg',
     'count', 'max', 'min', 'stdev', 'sum', 'var'
    :type aggregate: str or ~emsapi.models.enum
    :param format: Value formatting that should be performed on this field's
     value before returning.
     This will override the query's display value. Possible values include:
     'none', 'display'
    :type format: str or ~emsapi.models.enum
    """

    _validation = {
        'field_id': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'str'},
        'aggregate': {'key': 'aggregate', 'type': 'str'},
        'format': {'key': 'format', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaSelectColumn, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.aggregate = kwargs.get('aggregate', None)
        self.format = kwargs.get('format', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadStatus(Model):
    """This is sent as a response to an upload transfer status request.

    :param current_count: The current number of bytes the server has received
     on this transfer.
    :type current_count: long
    :param state: The state of the upload. Possible values include:
     'transferring', 'waitingProcessing', 'processing', 'processedSuccess',
     'processedFailure', 'abandonedTransfer', 'abandonedProcessing', 'canceled'
    :type state: str or ~emsapi.models.enum
    :param message: Contains a user-readable message about the status of the
     transfer.
    :type message: str
    """

    _attribute_map = {
        'current_count': {'key': 'currentCount', 'type': 'long'},
        'state': {'key': 'state', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoUploadUploadStatus, self).__init__(**kwargs)
        self.current_count = kwargs.get('current_count', None)
        self.state = kwargs.get('state', None)
        self.message = kwargs.get('message', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .analytic_operations import AnalyticOperations
from .analytic_set_operations import AnalyticSetOperations
from .asset_operations import AssetOperations
from .database_operations import DatabaseOperations
from .ems_profile_operations import EmsProfileOperations
from .ems_system_operations import EmsSystemOperations
from .html_documentation_operations import HtmlDocumentationOperations
from .navigation_operations import NavigationOperations
from .parameter_set_operations import ParameterSetOperations
from .profile_operations import ProfileOperations
from .tableau_operations import TableauOperations
from .trajectory_operations import TrajectoryOperations
from .transfer_operations import TransferOperations
from .upload_operations import UploadOperations
from .weather_operations import WeatherOperations

__all__ = [
    'AnalyticOperations',
    'AnalyticSetOperations',
    'AssetOperations',
    'DatabaseOperations',
    'EmsProfileOperations',
    'EmsSystemOperations',
    'HtmlDocumentationOperations',
    'NavigationOperations',
    'ParameterSetOperations',
    'ProfileOperations',
    'TableauOperations',
    'TrajectoryOperations',
    'TransferOperations',
    'UploadOperations',
    'WeatherOperations',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup(Model):
    """A container for analytic sets.

    :param name: The name of the group.
    :type name: str
    :param group_id: The ID of the group. This should be a relative path with
     backslashes replaced with colons.
    :type group_id: str
    :param groups: An array of groups contained by this group.
    :type groups:
     list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup]
    :param sets: An array of analytic sets contained by this group.
    :type sets: list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticSetAnalyticSet]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'group_id': {'key': 'groupId', 'type': 'str'},
        'groups': {'key': 'groups', 'type': '[AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup]'},
        'sets': {'key': 'sets', 'type': '[AdiEmsWebApiV2DtoAnalyticSetAnalyticSet]'},
    }

    def __init__(self, *, name: str=None, group_id: str=None, groups=None, sets=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup, self).__init__(**kwargs)
        self.name = name
        self.group_id = group_id
        self.groups = groups
        self.sets = sets



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class AnalyticOperations(object):
    """AnalyticOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def search_for_analytics(
            self, ems_system_id, text, group=None, max_results=None, category=None, custom_headers=None, raw=False, **operation_config):
        """Searches for analytics by name.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param text: The search terms used to find a list of analytics by
         name.
        :type text: str
        :param group: An optional group ID to specify where to limit the
         search. If not specified, all groups
         are searched.
        :type group: str
        :param max_results: The optional maximum number of matching results to
         return. If not specified, a
         default value of 200 is used. Use 0 to return all results.
        :type max_results: int
        :param category: The category of analytics to search, including
         "Full", "Physical" or "Logical". A
         null value specifies the default analytic set, which represents the
         full set of values exposed by the
         backing EMS system. Possible values include: 'full', 'physical',
         'logical'
        :type category: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.search_for_analytics.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        query_parameters['text'] = self._serialize.query("text", text, 'str')
        if group is not None:
            query_parameters['group'] = self._serialize.query("group", group, 'str')
        if max_results is not None:
            query_parameters['maxResults'] = self._serialize.query("max_results", max_results, 'int')
        if category is not None:
            query_parameters['category'] = self._serialize.query("category", category, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAnalyticInfo]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    search_for_analytics.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytics'}

    def get_analytic_info(
            self, ems_system_id, analytic_id, custom_headers=None, raw=False, **operation_config):
        """Retrieves metadata information associated with an analytic such as a
        description or units.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param analytic_id: The analytic ID for which data is retrieved. These
         identifiers are typically
         obtained from nodes in an analytic group tree.
        :type analytic_id:
         ~emsapi.models.AdiEmsWebApiV2ModelAnalyticAnalyticId
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_analytic_info.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(analytic_id, 'AdiEmsWebApiV2ModelAnalyticAnalyticId')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticInfo', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_analytic_info.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytics'}

    def search_for_flight_analytics(
            self, ems_system_id, flight_id, text, group=None, max_results=None, category=None, custom_headers=None, raw=False, **operation_config):
        """Searches for analytics by name for a specific flight.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         searching analytics.
        :type flight_id: int
        :param text: The search terms used to find a list of analytics by
         name.
        :type text: str
        :param group: An optional group ID to specify where to limit the
         search. If not specified, all groups are
         searched.
        :type group: str
        :param max_results: The optional maximum number of matching results to
         return. If not specified, a
         default value of 200 is used. Use 0 to return all results.
        :type max_results: int
        :param category: The category of analytics to search, including
         "Full", "Physical" or "Logical". A
         null value specifies the default analytic set, which represents the
         full set of values exposed by the
         backing EMS system. Possible values include: 'full', 'physical',
         'logical'
        :type category: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.search_for_flight_analytics.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        query_parameters['text'] = self._serialize.query("text", text, 'str')
        if group is not None:
            query_parameters['group'] = self._serialize.query("group", group, 'str')
        if max_results is not None:
            query_parameters['maxResults'] = self._serialize.query("max_results", max_results, 'int')
        if category is not None:
            query_parameters['category'] = self._serialize.query("category", category, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoAnalyticInfo]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    search_for_flight_analytics.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/analytics'}

    def get_flight_analytic_info(
            self, ems_system_id, flight_id, analytic_id, custom_headers=None, raw=False, **operation_config):
        """Retrieves metadata information associated with an analytic such as a
        description or units.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving the analytic information.
        :type flight_id: int
        :param analytic_id: The analytic ID for which data is retrieved. These
         identifiers are typically
         obtained from nodes in an analytic group tree.
        :type analytic_id:
         ~emsapi.models.AdiEmsWebApiV2ModelAnalyticAnalyticId
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_flight_analytic_info.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(analytic_id, 'AdiEmsWebApiV2ModelAnalyticAnalyticId')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticInfo', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_flight_analytic_info.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/analytics'}

    def get_analytic_group_contents(
            self, ems_system_id, analytic_group_id=None, category=None, custom_headers=None, raw=False, **operation_config):
        """Retrieves the contents of an analytic group, which is a hierarchical
        tree structure used to organize analytics.

        The contents of a group includes both subgroups and analytics.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param analytic_group_id: The ID of the group whose contents to
         retrieve.
         If not specified, the contents of the root group will be returned.
        :type analytic_group_id: str
        :param category: The category of analytics we are interested in.
         "Full", "Physical" or "Logical".
         A null value specifies the default analytic set, which represents the
         full set of values exposed by the backing EMS system. Possible values
         include: 'full', 'physical', 'logical'
        :type category: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_analytic_group_contents.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if analytic_group_id is not None:
            query_parameters['analyticGroupId'] = self._serialize.query("analytic_group_id", analytic_group_id, 'str')
        if category is not None:
            query_parameters['category'] = self._serialize.query("category", category, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticGroupContents', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_analytic_group_contents.metadata = {'url': '/v2/ems-systems/{emsSystemId}/analytic-groups'}

    def get_flight_analytic_group_contents(
            self, ems_system_id, flight_id, analytic_group_id=None, category=None, custom_headers=None, raw=False, **operation_config):
        """Retrieves the contents of an analytic group, which is a hierarchical
        tree structure used to organize analytics.

        <p>The contents of a group includes both subgroups and analytics.</p>
        <p>In this resource a flight is specified which will enumerate
        analytics specific to the flight such as
        physical parameters in addition to the analytics and groups which apply
        to all flights.</p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving the analytic group.
        :type flight_id: int
        :param analytic_group_id: The ID of the group whose contents to
         retrieve.
         If not specified, the contents of the root group will be returned
         instead.
        :type analytic_group_id: str
        :param category: The category of analytics we are interested in.
         "Full", "Physical" or "Logical".
         A null value specifies the default analytic set, which represents the
         full set of values exposed by the backing EMS system. Possible values
         include: 'full', 'physical', 'logical'
        :type category: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_flight_analytic_group_contents.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if analytic_group_id is not None:
            query_parameters['analyticGroupId'] = self._serialize.query("analytic_group_id", analytic_group_id, 'str')
        if category is not None:
            query_parameters['category'] = self._serialize.query("category", category, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoAnalyticGroupContents', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_flight_analytic_group_contents.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/analytic-groups'}

    def get_query_results(
            self, ems_system_id, flight_id, query, custom_headers=None, raw=False, **operation_config):
        """Queries offsets and values in time-series data for a specified flight
        and analytic.

        <p>
        This can be used to query for multiple analytics at the same time by
        providing more than one analytic ID
        in the query. Keep in mind that querying for many analytics might cause
        your request to take a longer
        period of time to complete.
        </p>
        <p>Below are some guidelines to consider when using this API.
        <ul><li>Use the "size" option to return a specified amount of
        interpolated samples. </li><li>Not specifying a "size" returns all data
        samples, but you can also use a range of "start" and "end"
        values to limit the amount of data returned. You can't use this option
        with the "unsampledDataMode"
        option.</li><li>Use the "offsets" option to return data for only a
        specified set of samples. If an analytic isn't
        sampled at the offset, its interpolated value is returned. You can't
        use this option with the
        "unsampledDataMode" option.</li><li>Use the "offsetType" option to
        return values only at sampled locations using the "sampledValues"
        option or at
        a specific sampling rate using the "samplingRate" option. Since these
        options are more complex and can leave
        sample locations with no value (i.e. the analytic isn't sampled at that
        location) or DNE values where the sample
        "does not exist" you can use the "offsetType" in conjunction with the
        "unsampledDataMode", the "unsampledValue",
        and/or the "doesNotExistValue" options. These are explained in greater
        detail below.</li><li>If you use the "unsampledDataMode" option with
        "offsetType" you can set how unsampled data is treated
        with one of the following options:
        <ul><li>"leaveBlank": Leaves any unsampled data locations as blank
        values. This is the default.</li><li><code>uniquePreviousSample</code>
        leaves values blank except when there is a previous valid sampled
        value that was skipped over due to the sampling rate if it is
        unchanged. This can be used to circumvent the
        issue of possibly returning all blank values when the provided sampling
        rate doesn't match the analytic's
        sampling rate.</li><li>"stairStep": Any unsampled values are filled
        with the last known sampled value.</li><li>"linearInterpolation": This
        performs a linear interpolation on the data to calculate a value for
        unsampled locations.</li><li>"parameterDefault": Some analytics define
        their own default for how to treat unsampled data. This option uses
        that default setting.</li><li><code>previousSample</code> leaves values
        blank except when there is a previous valid sampled
        value that was skipped over due to the sampling rate (regarless of
        change). This can be used to circumvent
        the issue of possibly returning all blank values when the provided
        sampling rate doesn't match the analytic's
        sampling rate or if the values are not changing.</li></ul></li><li>Use
        the "unsampledValue" to provide your own value to be used for unsampled
        values. This only applies when using "offsetType" queries.</li><li>Use
        the "doesNotExistValue" to provide your own value for values that are
        DNE. This only applies when using "offsetType" queries.</li><li>Use the
        "discretesAsStrings" to specify whether the values of discrete
        parameters should be their string representations or their numeric
        value. This only applies when using "offsetType"
        queries.</li></ul></p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record for which to
         query data.
        :type flight_id: int
        :param query: The information used to construct a query for which
         results are returned.
        :type query: ~emsapi.models.AdiEmsWebApiV2ModelAnalyticQuery
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_query_results.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(query, 'AdiEmsWebApiV2ModelAnalyticQuery')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2ModelAnalyticQueryResult', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_query_results.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/analytics/query'}

    def get_metadata(
            self, ems_system_id, flight_id, analytic_id, custom_headers=None, raw=False, **operation_config):
        """Returns the analytic metadata for a flight.

        <p>There are two special values always returned by the metadata
        call.</p>
        <ul>
        <li>Shape : [Single, Multiple, Unknown] : describes whether the result
        will be a single value or an array of values.</li>
        <li>DataType : [Real, Integer, String, Boolean, DateTime, Unknown] :
        describes the type of data returned.</li>
        </ul>
        The list of other properties
        returned are specific to each analytic but may include:
        <ul><li>Basic\Comments</li><li>Basic\Description</li><li>Information\Comments</li><li>Information\Description</li><li>Information\\UID</li><li>Parameter\Abbreviation</li><li>Parameter\Constant</li><li>Parameter\ID</li><li>Parameter\\Name</li><li>Value\Is
        Discrete</li><li>Value\Operational Rate Max</li><li>Value\Physical
        Range Min</li><li>Value\\Units</li><li>Value\Wraps</li></ul>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record for which to
         retrieve data.
        :type flight_id: int
        :param analytic_id: The analytic ID (wrapped in double quotes) for
         which metadata is retrieved. These
         identifiers are typically obtained from nodes in an analytic group
         tree.
        :type analytic_id:
         ~emsapi.models.AdiEmsWebApiV2ModelAnalyticAnalyticId
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_metadata.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(analytic_id, 'AdiEmsWebApiV2ModelAnalyticAnalyticId')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoMetadata', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_metadata.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/analytics/metadata'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary(Model):
    """AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary.

    :param glossary_version: The version of the EMS glossary the results were
     generated from.
    :type glossary_version: int
    :param profile_id: The local identifier of the profile
    :type profile_id: int
    :param profile_guid: The unique GUID of the profile in the system
    :type profile_guid: str
    :param current_version: The version of the associated profile
    :type current_version: int
    :param current_version_guid: The GUID identifier for the version of this
     profile.
    :type current_version_guid: str
    :param glossary_items: Array of entries in this glossary.
    :type glossary_items:
     list[~emsapi.models.AdiEmsWebApiV2DtoEmsProfileGlossaryItem]
    """

    _attribute_map = {
        'glossary_version': {'key': 'glossaryVersion', 'type': 'int'},
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_guid': {'key': 'profileGuid', 'type': 'str'},
        'current_version': {'key': 'currentVersion', 'type': 'int'},
        'current_version_guid': {'key': 'currentVersionGuid', 'type': 'str'},
        'glossary_items': {'key': 'glossaryItems', 'type': '[AdiEmsWebApiV2DtoEmsProfileGlossaryItem]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary, self).__init__(**kwargs)
        self.glossary_version = kwargs.get('glossary_version', None)
        self.profile_id = kwargs.get('profile_id', None)
        self.profile_guid = kwargs.get('profile_guid', None)
        self.current_version = kwargs.get('current_version', None)
        self.current_version_guid = kwargs.get('current_version_guid', None)
        self.glossary_items = kwargs.get('glossary_items', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileGlossaryItem(Model):
    """Represents a single entry for an item in a profile glossary.

    :param record_type: A character representing a profile glossary entries
     record type.
    :type record_type: str
    :param scope: A character representing the scope of this entry.
    :type scope: str
    :param item_id: A unique integer id for this item.
    :type item_id: int
    :param event_type_id: The event type id of this item. This is only
     available for valid event types.
    :type event_type_id: int
    :param data_type: A character representing the data type of this entry.
    :type data_type: str
    :param logical_id: A GUID defining this item's logical id.
    :type logical_id: str
    :param name: The name provided for this item.
    :type name: str
    :param units: An optional unit provided for this item.
    :type units: str
    :param first_associated_item_type: The item type of the first associated
     item.
    :type first_associated_item_type: str
    :param first_associated_item_scope: The scope of the first associated
     item.
    :type first_associated_item_scope: str
    :param first_associated_item_id: The item id of the first associated item.
    :type first_associated_item_id: int
    :param second_associated_item_type: The item type of the second associated
     item.
    :type second_associated_item_type: str
    :param second_associated_item_scope: The scope of the second associated
     item.
    :type second_associated_item_scope: str
    :param second_associated_item_id: The item id of the second associated
     item.
    :type second_associated_item_id: int
    """

    _attribute_map = {
        'record_type': {'key': 'recordType', 'type': 'str'},
        'scope': {'key': 'scope', 'type': 'str'},
        'item_id': {'key': 'itemId', 'type': 'int'},
        'event_type_id': {'key': 'eventTypeId', 'type': 'int'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'logical_id': {'key': 'logicalId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'units': {'key': 'units', 'type': 'str'},
        'first_associated_item_type': {'key': 'firstAssociatedItemType', 'type': 'str'},
        'first_associated_item_scope': {'key': 'firstAssociatedItemScope', 'type': 'str'},
        'first_associated_item_id': {'key': 'firstAssociatedItemId', 'type': 'int'},
        'second_associated_item_type': {'key': 'secondAssociatedItemType', 'type': 'str'},
        'second_associated_item_scope': {'key': 'secondAssociatedItemScope', 'type': 'str'},
        'second_associated_item_id': {'key': 'secondAssociatedItemId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileGlossaryItem, self).__init__(**kwargs)
        self.record_type = kwargs.get('record_type', None)
        self.scope = kwargs.get('scope', None)
        self.item_id = kwargs.get('item_id', None)
        self.event_type_id = kwargs.get('event_type_id', None)
        self.data_type = kwargs.get('data_type', None)
        self.logical_id = kwargs.get('logical_id', None)
        self.name = kwargs.get('name', None)
        self.units = kwargs.get('units', None)
        self.first_associated_item_type = kwargs.get('first_associated_item_type', None)
        self.first_associated_item_scope = kwargs.get('first_associated_item_scope', None)
        self.first_associated_item_id = kwargs.get('first_associated_item_id', None)
        self.second_associated_item_type = kwargs.get('second_associated_item_type', None)
        self.second_associated_item_scope = kwargs.get('second_associated_item_scope', None)
        self.second_associated_item_id = kwargs.get('second_associated_item_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestProject(Model):
    """AdiEmsWebSharedTableauRestProject.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param content_permissions:
    :type content_permissions: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'content_permissions': {'key': 'contentPermissions', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, name: str=None, description: str=None, content_permissions: str=None, **kwargs) -> None:
        super(AdiEmsWebSharedTableauRestProject, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.description = description
        self.content_permissions = content_permissions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticAnalyticId(Model):
    """Provides an identifier for an individual analytic.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier of the analytic.
    :type id: str
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
    }

    def __init__(self, *, id: str, **kwargs) -> None:
        super(AdiEmsWebApiV2ModelAnalyticAnalyticId, self).__init__(**kwargs)
        self.id = id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaField(Model):
    """Represents an individual field that can be accessed within a data source.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier for the field
    :type id: str
    :param type: Required. The data type of the underlying data stored for the
     field. Possible values include: 'boolean', 'dateTime', 'discrete',
     'number', 'string'
    :type type: str or ~emsapi.models.enum
    :param name: Required. The display name for the field
    :type name: str
    """

    _validation = {
        'id': {'required': True},
        'type': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, *, id: str, type, name: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaField, self).__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiModelError(Model):
    """AdiEmsWebApiModelError.

    All required parameters must be populated in order to send to Azure.

    :param message: Required.
    :type message: str
    :param message_detail: Required.
    :type message_detail: str
    :param unexpected: Required.
    :type unexpected: bool
    """

    _validation = {
        'message': {'required': True},
        'message_detail': {'required': True},
        'unexpected': {'required': True},
    }

    _attribute_map = {
        'message': {'key': 'message', 'type': 'str'},
        'message_detail': {'key': 'messageDetail', 'type': 'str'},
        'unexpected': {'key': 'unexpected', 'type': 'bool'},
    }

    def __init__(self, *, message: str, message_detail: str, unexpected: bool, **kwargs) -> None:
        super(AdiEmsWebApiModelError, self).__init__(**kwargs)
        self.message = message
        self.message_detail = message_detail
        self.unexpected = unexpected



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafIcingCondition(Model):
    """Describes a forecast icing condition.

    :param intensity: The intensity code associated with the icing. Uses the
     following values:
     0 - Trace icing or none,
     1 - Light mixed icing,
     2 - Light rime icing in cloud,
     3 - Light clear icing in precipitation,
     4 - Moderate mixed icing,
     5 - Moderate rime icing in cloud,
     6 - Moderate clear icing in precipitation,
     7 - Severe mixed icing,
     8 - Severe rime icing in cloud,
     9 - Severe clear icing in precipitation
    :type intensity: int
    :param minimum: The base limit of the icing layer in feet
    :type minimum: int
    :param maximum: The top limit of the icing layer in feet
    :type maximum: int
    """

    _attribute_map = {
        'intensity': {'key': 'intensity', 'type': 'int'},
        'minimum': {'key': 'minimum', 'type': 'int'},
        'maximum': {'key': 'maximum', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherTafIcingCondition, self).__init__(**kwargs)
        self.intensity = kwargs.get('intensity', None)
        self.minimum = kwargs.get('minimum', None)
        self.maximum = kwargs.get('maximum', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAnalyticGroupContents(Model):
    """Represents the contents of an analytic group.

    :param groups: An in-order listing of the groups contained in the
     specified group
    :type groups: list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticGroup]
    :param analytics: An in-order listing of the analytics contained in the
     specified group
    :type analytics: list[~emsapi.models.AdiEmsWebApiV2DtoAnalyticInfo]
    """

    _attribute_map = {
        'groups': {'key': 'groups', 'type': '[AdiEmsWebApiV2DtoAnalyticGroup]'},
        'analytics': {'key': 'analytics', 'type': '[AdiEmsWebApiV2DtoAnalyticInfo]'},
    }

    def __init__(self, *, groups=None, analytics=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoAnalyticGroupContents, self).__init__(**kwargs)
        self.groups = groups
        self.analytics = analytics



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileEvent(Model):
    """Represents an APM event definition.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The definition ID of this event
    :type id: int
    :param name: Required. The name of the event
    :type name: str
    :param comments: Required. Comments associated with this event
    :type comments: str
    :param parameter_set: The parameter set associated with the event if any
    :type parameter_set:
     ~emsapi.models.AdiEmsWebApiV2DtoParameterSetParameterSet
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'comments': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'comments': {'key': 'comments', 'type': 'str'},
        'parameter_set': {'key': 'parameterSet', 'type': 'AdiEmsWebApiV2DtoParameterSetParameterSet'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoProfileEvent, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.comments = kwargs.get('comments', None)
        self.parameter_set = kwargs.get('parameter_set', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafTafReport(Model):
    """Represents an individual TAF report.

    All required parameters must be populated in order to send to Azure.

    :param parse_errors: Error messages delimited by newlines if there were
     non-critical issues parsing the raw TAF string
    :type parse_errors: str
    :param issued: Required. The time point that this TAF report was issued
    :type issued: datetime
    :param airport: Required. The airport that issued the TAF report
    :type airport: str
    :param valid_from: Required. The starting time point that this TAF report
     is valid
    :type valid_from: datetime
    :param valid_to: Required. The ending time point that this TAF report is
     valid
    :type valid_to: datetime
    :param predictions: A list of forecast predictions in the TAF
    :type predictions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafPrediction]
    :param header_text: Required. The header text for the TAF
    :type header_text: str
    :param flight_match_type: The time and place relative to a specific flight
     that this forecast data would match to. Possible values include: 'none',
     'takeoffAtDispatch', 'landingAtDispatch', 'alternateAtDispatch',
     'landingAtTakeoff', 'alternateAtTakeoff', 'alternateAtLanding'
    :type flight_match_type: str or ~emsapi.models.enum
    :param matched_prediction: The forecast data that matches to a specific
     flight
    :type matched_prediction:
     ~emsapi.models.AdiEmsWebApiV2DtoWeatherTafPrediction
    """

    _validation = {
        'issued': {'required': True},
        'airport': {'required': True},
        'valid_from': {'required': True},
        'valid_to': {'required': True},
        'header_text': {'required': True},
    }

    _attribute_map = {
        'parse_errors': {'key': 'parseErrors', 'type': 'str'},
        'issued': {'key': 'issued', 'type': 'iso-8601'},
        'airport': {'key': 'airport', 'type': 'str'},
        'valid_from': {'key': 'validFrom', 'type': 'iso-8601'},
        'valid_to': {'key': 'validTo', 'type': 'iso-8601'},
        'predictions': {'key': 'predictions', 'type': '[AdiEmsWebApiV2DtoWeatherTafPrediction]'},
        'header_text': {'key': 'headerText', 'type': 'str'},
        'flight_match_type': {'key': 'flightMatchType', 'type': 'str'},
        'matched_prediction': {'key': 'matchedPrediction', 'type': 'AdiEmsWebApiV2DtoWeatherTafPrediction'},
    }

    def __init__(self, *, issued, airport: str, valid_from, valid_to, header_text: str, parse_errors: str=None, predictions=None, flight_match_type=None, matched_prediction=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherTafTafReport, self).__init__(**kwargs)
        self.parse_errors = parse_errors
        self.issued = issued
        self.airport = airport
        self.valid_from = valid_from
        self.valid_to = valid_to
        self.predictions = predictions
        self.header_text = header_text
        self.flight_match_type = flight_match_type
        self.matched_prediction = matched_prediction



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileResultsEventRecord(Model):
    """Encapsulates information about an event result stored in the database.

    All required parameters must be populated in order to send to Azure.

    :param record_number: Required. The unique integer ID of the event in the
     database
    :type record_number: int
    :param event_type: Required. The unique ID of the event definition that
     generated the event
    :type event_type: int
    :param phase_of_flight: Required. The phase of flight where the event
     occurred (which is a value from the EMS phase of flight list)
    :type phase_of_flight: int
    :param severity: Required. The event severity (which is a value from the
     EMS severity list)
    :type severity: int
    :param status: Required. The status of the event (which is a value from
     the EMS status list). Typically this defaults to
     0 for new events, but in some data-merge scenarios we need to import a
     non-default value
     from a remote system
    :type status: int
    :param false_positive: Required. The false positive value for the event (a
     value from the EMS false positive list).
     Typically this defaults to 0 for new events, but in some data-merge
     scenarios we
     need to import a non-default value from a remote system
    :type false_positive: int
    :param start_time: Required. The start offset for the event
    :type start_time: float
    :param end_time: Required. The end offset for the event
    :type end_time: float
    :param global_measurements: Required. The global event measurement results
     (defined for all events)
    :type global_measurements:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param global_timepoints: Required. The global event timepoint results
     (defined for all events)
    :type global_timepoints:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param local_measurements: Required. The event-specific measurement
     results (different for each event type)
    :type local_measurements:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param local_timepoints: Required. The event-specific timepoint results
     (different for each event type)
    :type local_timepoints:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param comments: Required. The event comments. Usually this is empty, but
     it's required for some data-merge
     scenarios.
    :type comments:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultComment]
    """

    _validation = {
        'record_number': {'required': True},
        'event_type': {'required': True},
        'phase_of_flight': {'required': True},
        'severity': {'required': True},
        'status': {'required': True},
        'false_positive': {'required': True},
        'start_time': {'required': True},
        'end_time': {'required': True},
        'global_measurements': {'required': True},
        'global_timepoints': {'required': True},
        'local_measurements': {'required': True},
        'local_timepoints': {'required': True},
        'comments': {'required': True},
    }

    _attribute_map = {
        'record_number': {'key': 'recordNumber', 'type': 'int'},
        'event_type': {'key': 'eventType', 'type': 'int'},
        'phase_of_flight': {'key': 'phaseOfFlight', 'type': 'int'},
        'severity': {'key': 'severity', 'type': 'int'},
        'status': {'key': 'status', 'type': 'int'},
        'false_positive': {'key': 'falsePositive', 'type': 'int'},
        'start_time': {'key': 'startTime', 'type': 'float'},
        'end_time': {'key': 'endTime', 'type': 'float'},
        'global_measurements': {'key': 'globalMeasurements', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'global_timepoints': {'key': 'globalTimepoints', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'local_measurements': {'key': 'localMeasurements', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'local_timepoints': {'key': 'localTimepoints', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'comments': {'key': 'comments', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultComment]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoProfileProfileResultsEventRecord, self).__init__(**kwargs)
        self.record_number = kwargs.get('record_number', None)
        self.event_type = kwargs.get('event_type', None)
        self.phase_of_flight = kwargs.get('phase_of_flight', None)
        self.severity = kwargs.get('severity', None)
        self.status = kwargs.get('status', None)
        self.false_positive = kwargs.get('false_positive', None)
        self.start_time = kwargs.get('start_time', None)
        self.end_time = kwargs.get('end_time', None)
        self.global_measurements = kwargs.get('global_measurements', None)
        self.global_timepoints = kwargs.get('global_timepoints', None)
        self.local_measurements = kwargs.get('local_measurements', None)
        self.local_timepoints = kwargs.get('local_timepoints', None)
        self.comments = kwargs.get('comments', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class EmsProfileOperations(object):
    """EmsProfileOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_ems_profile_results(
            self, ems_system_id, flight_id, profile_id, custom_headers=None, raw=False, **operation_config):
        """[DEPRECATED] Returns profile results for a specific flight.

        This route has been replaced by
        'v2/ems-systems/{emsSystemId}/flights/{flightId}/profiles/{profileId}/query'
        route which aligns better with existing API conventions.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving profile information.
        :type flight_id: int
        :param profile_id: The unique identifier of the APM profile, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0" for
         the library flight safety events profile.
        :type profile_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_ems_profile_results.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoEmsProfileProfileResults', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_ems_profile_results.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/ems-profiles/{profileId}'}

    def get_ems_profiles(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """[DEPRECATED] Returns information about a set of profiles for an EMS
        system.

        This route has been replaced by
        'v2/ems-systems/{emsSystemId}/profile-groups' and
        'v2/ems-systems/{emsSystemId}/profiles' routes which align better with
        existing API conventions and offers more features like searching and
        enumerating the profile group
        hierarchy.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_ems_profiles.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoEmsProfileEmsProfile]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_ems_profiles.metadata = {'url': '/v2/ems-systems/{emsSystemId}/ems-profiles'}

    def get_ems_profile_glossary(
            self, ems_system_id, profile_id, profile_version_number=None, format=None, custom_headers=None, raw=False, **operation_config):
        """[DEPRECATED] Returns the file content of an APM profile glossary for a
        specific profile and version.

        <p>
        This route has been replaced by
        'v2/ems-systems/{emsSystemId}/profiles/{profileId}/glossary' route
        which
        aligns better with existing API conventions and offers more features
        like returning JSON responses with
        a more detailed glossary.
        </p>
        <p>
        This API is intended to be used in conjunction with the
        "ems-systems/{emsSystemId}/flights/{flightId}/ems-profiles/{profileId}"
        API used to return APM (Automated
        Parameter Measurement) profile result. Using the data returned from
        this API you can interpret and
        better understand the results returned in  the profile results.
        </p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param profile_id: The unique identifier of the APM profile, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0" for
         the library flight safety events profile.
        :type profile_id: str
        :param profile_version_number: Numbered version of an APM profile. The
         current version of the profile
         will be used if a version number is not provided.
        :type profile_version_number: int
        :param format: The format the glossary should be returned in. This
         defaults to CSV. Possible values include: 'json', 'csv'
        :type format: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_ems_profile_glossary.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if profile_version_number is not None:
            query_parameters['profileVersionNumber'] = self._serialize.query("profile_version_number", profile_version_number, 'int')
        if format is not None:
            query_parameters['format'] = self._serialize.query("format", format, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_ems_profile_glossary.metadata = {'url': '/v2/ems-systems/{emsSystemId}/ems-profiles/{profileId}/glossary'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class NavigationOperations(object):
    """NavigationOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_airports(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """Returns the list of active airports from the system.

        Each EMS system has a list of active airports, which are actually in
        use in collected
        flight data. This route returns all of the information on those
        airports. The IDs specified
        in the returned data should be used elsewhere in these APIs.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_airports.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoNavigationNavigationAirport]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_airports.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/airports'}

    def get_runways(
            self, ems_system_id, airport_id, custom_headers=None, raw=False, **operation_config):
        """Returns information on the runways connected to an airport.

        Each airport is associated with one or more runways.
        This route returns information on the runways for a single airport.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param airport_id: The airport ID, obtained from the "airports" route.
        :type airport_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_runways.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'airportId': self._serialize.url("airport_id", airport_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoNavigationNavigationRunway]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_runways.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/airports/{airportId}/runways'}

    def get_procedures(
            self, ems_system_id, airport_id, custom_headers=None, raw=False, **operation_config):
        """Returns information on the procedures connected to an airport.

        Each airport is associated with one or more procedures, specifying how
        to take off and land.
        This route returns information on the procedures for a single airport.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param airport_id: The airport ID, obtained from the "airports" route.
        :type airport_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_procedures.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'airportId': self._serialize.url("airport_id", airport_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoNavigationNavigationProcedure]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_procedures.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/airports/{airportId}/procedures'}

    def get_procedure_segments(
            self, ems_system_id, procedure_id, custom_headers=None, raw=False, **operation_config):
        """Returns information on the segments of procedures connected to an
        airport.

        Each airport is associated with one or more procedures, specifying how
        to take off and land.
        This route returns all of the information we have on the segments for a
        single procedure.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param procedure_id: The procedure ID, obtained from the "procedures"
         route.
        :type procedure_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_procedure_segments.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'procedureId': self._serialize.url("procedure_id", procedure_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_procedure_segments.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/procedures/{procedureId}/segments'}

    def get_waypoint(
            self, ems_system_id, waypoint_id, custom_headers=None, raw=False, **operation_config):
        """Returns information on a waypoint.

        Waypoints are referenced from procedures obtained from the "procedures"
        route. These
        IDs can be used to look up further info on waypoints.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param waypoint_id: The waypoint ID, obtained from the "procedures"
         route.
        :type waypoint_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_waypoint.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'waypointId': self._serialize.url("waypoint_id", waypoint_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoNavigationNavigationWaypoint', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_waypoint.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/waypoints/{waypointId}'}

    def get_navaid(
            self, ems_system_id, navaid_id, custom_headers=None, raw=False, **operation_config):
        """Returns information on a navaid.

        Navaids are referenced from procedures obtained from the "procedures"
        route. These
        IDs can be used to look up further info on navaids.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param navaid_id: The navaid ID, obtained from the "procedures" route.
        :type navaid_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_navaid.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'navaidId': self._serialize.url("navaid_id", navaid_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoNavigationNavigationNavaid', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_navaid.metadata = {'url': '/v2/ems-systems/{emsSystemId}/navigation/navaids/{navaidId}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus(Model):
    """A single flight result within a larger download result.

    :param flight_record: The flight record for the flight
    :type flight_record: int
    :param flight_status: A description of the flight record's processing
     state. This should be checked before assuming
     that the flight is correct and complete. Possible values include:
     'notProcessed', 'processed', 'failure'
    :type flight_status: str or ~emsapi.models.enum
    """

    _attribute_map = {
        'flight_record': {'key': 'flightRecord', 'type': 'int'},
        'flight_status': {'key': 'flightStatus', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus, self).__init__(**kwargs)
        self.flight_record = kwargs.get('flight_record', None)
        self.flight_status = kwargs.get('flight_status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileGroup(Model):
    """Represents a folder in the profile tree of an EMS installation.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The globally unique ID for the profile group
    :type id: str
    :param name: Required. The display name of the profile group
    :type name: str
    :param description: The optional description that briefly describes the
     profile group
    :type description: str
    :param groups: An ordered listing of child profile groups contained in
     this group
    :type groups: list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileGroup]
    :param profiles: An ordered listing of child profiles contained in this
     group
    :type profiles: list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfile]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'groups': {'key': 'groups', 'type': '[AdiEmsWebApiV2DtoProfileProfileGroup]'},
        'profiles': {'key': 'profiles', 'type': '[AdiEmsWebApiV2DtoProfileProfile]'},
    }

    def __init__(self, *, id: str, name: str, description: str=None, groups=None, profiles=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoProfileProfileGroup, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.description = description
        self.groups = groups
        self.profiles = profiles



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaFilterArgument(Model):
    """Represents an argument in a filter.

    All required parameters must be populated in order to send to Azure.

    :param type: Required. The type of the filter argument, describing the
     role of the argument. Possible values include: 'none', 'filter', 'field',
     'constant'
    :type type: str or ~emsapi.models.enum
    :param value: Required. The value represented by the filter argument.
    :type value: object
    """

    _validation = {
        'type': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaFilterArgument, self).__init__(**kwargs)
        self.type = kwargs.get('type', None)
        self.value = kwargs.get('value', None)
